cosmpy.protos.ibc.core.client.v1 package — cosmpy documentation

# cosmpy.protos.ibc.core.client.v1 package

## Submodules

## cosmpy.protos.ibc.core.client.v1.client_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.client.v1.client_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.client.v1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.client.v1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.client.v1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.client.v1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.client.v1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service

  static ClientParams(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ClientStates(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConsensusStates(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.client.v1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service

  ClientParams(request, context)

    ClientParams queries all parameters of the ibc client.

  ClientState(request, context)

    ClientState queries an IBC light client.

  ClientStates(request, context)

    ClientStates queries all the IBC light clients of a chain.

  ConsensusState(request, context)

    ConsensusState queries a consensus state associated with a client state at a given height.

  ConsensusStates(request, context)

    ConsensusStates queries all the consensus state associated with a given client.

class cosmpy.protos.ibc.core.client.v1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service

cosmpy.protos.ibc.core.client.v1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.ibc.core.client.v1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the ibc/client Msg service.

  static CreateClient(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SubmitMisbehaviour(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UpdateClient(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UpgradeClient(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the ibc/client Msg service.

  CreateClient(request, context)

    CreateClient defines a rpc handler method for MsgCreateClient.

  SubmitMisbehaviour(request, context)

    SubmitMisbehaviour defines a rpc handler method for MsgSubmitMisbehaviour.

  UpdateClient(request, context)

    UpdateClient defines a rpc handler method for MsgUpdateClient.

  UpgradeClient(request, context)

    UpgradeClient defines a rpc handler method for MsgUpgradeClient.

class cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the ibc/client Msg service.

cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents